==> zio-aws-serverlessapplicationrepository_2.12-5.17.153.3-sources.jar: zio/aws/serverlessapplicationrepository/model/GetApplicationRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetApplicationRequest(
    applicationId: __string,
    semanticVersion: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest = {
    import GetApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
      .builder()
      .applicationId(applicationId: java.lang.String)
      .optionallyWith(semanticVersion.map(value => value: java.lang.String))(
        _.semanticVersion
      )
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.GetApplicationRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.GetApplicationRequest
      .wrap(buildAwsValue())
}
object GetApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.GetApplicationRequest =
      zio.aws.serverlessapplicationrepository.model.GetApplicationRequest(
        applicationId,
        semanticVersion.map(value => value)
      )
    def applicationId: __string
    def semanticVersion: Option[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getSemanticVersion: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("semanticVersion", semanticVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
  ) extends zio.aws.serverlessapplicationrepository.model.GetApplicationRequest.ReadOnly {
    override val applicationId: __string = impl.applicationId(): __string
    override val semanticVersion: Option[__string] =
      scala.Option(impl.semanticVersion()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
  ): zio.aws.serverlessapplicationrepository.model.GetApplicationRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-serverlessapplicationrepository_2.13-5.17.103.1-sources.jar: zio/aws/serverlessapplicationrepository/model/GetApplicationRequest.scala <==
package zio.aws.serverlessapplicationrepository.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.serverlessapplicationrepository.model.primitives.__string
import scala.jdk.CollectionConverters._
final case class GetApplicationRequest(
    applicationId: __string,
    semanticVersion: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest = {
    import GetApplicationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
      .builder()
      .applicationId(__string.unwrap(applicationId): java.lang.String)
      .optionallyWith(
        semanticVersion.map(value => __string.unwrap(value): java.lang.String)
      )(_.semanticVersion)
      .build()
  }
  def asReadOnly
      : zio.aws.serverlessapplicationrepository.model.GetApplicationRequest.ReadOnly =
    zio.aws.serverlessapplicationrepository.model.GetApplicationRequest
      .wrap(buildAwsValue())
}
object GetApplicationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.serverlessapplicationrepository.model.GetApplicationRequest =
      zio.aws.serverlessapplicationrepository.model.GetApplicationRequest(
        applicationId,
        semanticVersion.map(value => value)
      )
    def applicationId: __string
    def semanticVersion: Option[__string]
    def getApplicationId: ZIO[Any, Nothing, __string] =
      ZIO.succeed(applicationId)
    def getSemanticVersion: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("semanticVersion", semanticVersion)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
  ) extends zio.aws.serverlessapplicationrepository.model.GetApplicationRequest.ReadOnly {
    override val applicationId: __string =
      zio.aws.serverlessapplicationrepository.model.primitives
        .__string(impl.applicationId())
    override val semanticVersion: Option[__string] = scala
      .Option(impl.semanticVersion())
      .map(value =>
        zio.aws.serverlessapplicationrepository.model.primitives.__string(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.serverlessapplicationrepository.model.GetApplicationRequest
  ): zio.aws.serverlessapplicationrepository.model.GetApplicationRequest.ReadOnly =
    new Wrapper(impl)
}
